@@ -7,15 +7,13 @@ LinearSum_ = "LinearSum"
 Vector_ = "Vector"
 EnhancedAccuracy_ = "EnhancedAccuracy"
 Logarithmic_ = "Logarithmic"
-TopsisOriginal_ = "TopsisOriginal"
 
 NORMALIZATION_METHODS = [LinearMinMax_,
                          LinearMax_,
                          LinearSum_,
                          Vector_,
                          EnhancedAccuracy_,
-                         Logarithmic_,
-                         TopsisOriginal_]
+                         Logarithmic_]
                          
 SAATY_SCALE = [1, 2 ,3 ,4 ,5 ,6 ,7 ,8 ,9, 1/2, 1/3, 1/4, 1/5, 1/6, 1/7, 1/8, 1/9]
 
