@@ -172,9 +172,9 @@ class MCDA:
         else:
             raise ValueError("Invalid signals! It's must be a list of 1 or -1")
 
-    def topsis(self, normalization_method=TopsisOriginal_):
+    def topsis(self, normalization_method=Vector_):
         self.__set_normalization_method(normalization_method)      
-        self.__normalize()
+        self.__normalize(True)
         self.__weighting_from_normalized()
         self.__xis()
         self.__topsis()
@@ -210,118 +210,150 @@ class MCDA:
         else:
             raise ValueError("Invalid parameter! Use a method defined in constants. e.g. normalization_D, zScore etc...")
 
-    def __normalize(self):
+    def __normalize(self, ignore_signals=False):
         if self.normalization_method == Vector_:
-            self.__norm_Vector()
+            self.__norm_Vector(ignore_signals)
         elif self.normalization_method == LinearSum_:
-            self.__norm_LinearSum()
+            self.__norm_LinearSum(ignore_signals)
         elif self.normalization_method == LinearMinMax_:
-            self.__norm_LinearMinMax()
+            self.__norm_LinearMinMax(ignore_signals)
         elif self.normalization_method == LinearMax_:
-            self.__norm_LinearMax()
+            self.__norm_LinearMax(ignore_signals)
         elif self.normalization_method == EnhancedAccuracy_:
-            self.__norm_EnhancedAccuracy()
+            self.__norm_EnhancedAccuracy(ignore_signals)
         elif self.normalization_method == Logarithmic_:
-            self.__norm_Logarithmic()
+            self.__norm_Logarithmic(ignore_signals)
         elif self.normalization_method == TopsisOriginal_:
             self.__norm_TopsisOriginal()
         else:
             self.df_normalized = self.df_original
 
-    def __norm_ZScore(self):
+    def __norm_ZScore(self, ignore_signals=False):
         normalized = (self.df_original.iloc[:, 1:] - self.df_original.iloc[:, 1:].mean(axis=0))/self.df_original.iloc[:, 1:].std(axis=0)
         self.df_normalized = pd.DataFrame(self.df_original.iloc[:, 0]).join(normalized)
+               
+        # make nomalized matrix based in signals
+        normalized = pd.DataFrame(self.df_original.iloc[:, 0])
+        if ignore_signals is True:
+            normalized = normalized.join(normalized_max.iloc[:, :])
+        else:
+            i = 0
+            for s in self.signals:
+                if s == 1:
+                    normalized = normalized.join(normalized_max.iloc[:, i])
+                else:
+                    normalized = normalized.join(normalized_min.iloc[:, i])
+                i = i + 1
+        
+        self.df_normalized = normalized
 
-    def __norm_EnhancedAccuracy(self):
+    def __norm_EnhancedAccuracy(self, ignore_signals=False):
         # _max for maximizing 
         normalized_max = 1 - (self.df_original.iloc[:, 1:].max(axis=0)-self.df_original.iloc[:, 1:])/((self.df_original.iloc[:, 1:].max(axis=0)-self.df_original.iloc[:, 1:]).sum(axis=0))
         # _min for minimizing 
         normalized_min = 1 - (self.df_original.iloc[:, 1:]-self.df_original.iloc[:, 1:].min(axis=0))/((self.df_original.iloc[:, 1:]-self.df_original.iloc[:, 1:].min(axis=0)).sum(axis=0))
-        
+       
         # make nomalized matrix based in signals
         normalized = pd.DataFrame(self.df_original.iloc[:, 0])
-        i = 0
-        for s in self.signals:
-            if s == 1:
-                normalized = normalized.join(normalized_max.iloc[:, i])
-            else:
-                normalized = normalized.join(normalized_min.iloc[:, i])
-            i = i + 1
+        if ignore_signals is True:
+            normalized = normalized.join(normalized_max.iloc[:, :])
+        else:
+            i = 0
+            for s in self.signals:
+                if s == 1:
+                    normalized = normalized.join(normalized_max.iloc[:, i])
+                else:
+                    normalized = normalized.join(normalized_min.iloc[:, i])
+                i = i + 1
         
         self.df_normalized = normalized
 
-    def __norm_Logarithmic(self):
+    def __norm_Logarithmic(self, ignore_signals=False):
         # _max for maximizing 
         normalized_max = np.log2(self.df_original.iloc[:, 1:]) / np.log2( np.log2(self.df_original.iloc[:, 1:]).prod(axis = 0) * self.df_original.iloc[:, 1:] )
         # _min for minimizing 
         normalized_min = 1 - ( (1 - normalized_max) / ( normalized_max.shape[0] - 1) )
+          
         # make nomalized matrix based in signals
         normalized = pd.DataFrame(self.df_original.iloc[:, 0])
-        i = 0
-        for s in self.signals:
-            if s == 1:
-                normalized = normalized.join(normalized_max.iloc[:, i])
-            else:
-                normalized = normalized.join(normalized_min.iloc[:, i])
-            i = i + 1
+        if ignore_signals is True:
+            normalized = normalized.join(normalized_max.iloc[:, :])
+        else:
+            i = 0
+            for s in self.signals:
+                if s == 1:
+                    normalized = normalized.join(normalized_max.iloc[:, i])
+                else:
+                    normalized = normalized.join(normalized_min.iloc[:, i])
+                i = i + 1
         
         self.df_normalized = normalized
 
-    def __norm_LinearMax(self):
+    def __norm_LinearMax(self, ignore_signals=False):
         # _max for maximizing 
         normalized_max = (self.df_original.iloc[:, 1:]/self.df_original.iloc[:, 1:].max(axis=0))
         # _min for minimizing 
         normalized_min = (self.df_original.iloc[:, 1:].min(axis=0)/self.df_original.iloc[:, 1:])
-        
+               
         # make nomalized matrix based in signals
         normalized = pd.DataFrame(self.df_original.iloc[:, 0])
-        i = 0
-        for s in self.signals:
-            if s == 1:
-                normalized = normalized.join(normalized_max.iloc[:, i])
-            else:
-                normalized = normalized.join(normalized_min.iloc[:, i])
-            i = i + 1
+        if ignore_signals is True:
+            normalized = normalized.join(normalized_max.iloc[:, :])
+        else:
+            i = 0
+            for s in self.signals:
+                if s == 1:
+                    normalized = normalized.join(normalized_max.iloc[:, i])
+                else:
+                    normalized = normalized.join(normalized_min.iloc[:, i])
+                i = i + 1
         
         self.df_normalized = normalized
 
-    def __norm_LinearMinMax(self):
+    def __norm_LinearMinMax(self, ignore_signals=False):
         # _max for maximizing 
         normalized_max = (self.df_original.iloc[:, 1:]-self.df_original.iloc[:, 1:].min(axis=0))/(self.df_original.iloc[:, 1:].max(axis=0)-self.df_original.iloc[:, 1:].min(axis=0))
         # _min for minimizing 
         normalized_min = (self.df_original.iloc[:, 1:].max(axis=0)-self.df_original.iloc[:, 1:])/(self.df_original.iloc[:, 1:].max(axis=0)-self.df_original.iloc[:, 1:].min(axis=0))
-        
+               
         # make nomalized matrix based in signals
         normalized = pd.DataFrame(self.df_original.iloc[:, 0])
-        i = 0
-        for s in self.signals:
-            if s == 1:
-                normalized = normalized.join(normalized_max.iloc[:, i])
-            else:
-                normalized = normalized.join(normalized_min.iloc[:, i])
-            i = i + 1
+        if ignore_signals is True:
+            normalized = normalized.join(normalized_max.iloc[:, :])
+        else:
+            i = 0
+            for s in self.signals:
+                if s == 1:
+                    normalized = normalized.join(normalized_max.iloc[:, i])
+                else:
+                    normalized = normalized.join(normalized_min.iloc[:, i])
+                i = i + 1
         
         self.df_normalized = normalized
 
-    def __norm_LinearSum(self):
+    def __norm_LinearSum(self, ignore_signals=False):
         # _max for maximizing 
         normalized_max = self.df_original.iloc[:, 1:]/self.df_original.iloc[:, 1:].sum(axis=0)
         # _min for minimizing 
         normalized_min = (1/self.df_original.iloc[:, 1:])/(1/self.df_original.iloc[:, 1:]).sum(axis=0)
         
+       
         # make nomalized matrix based in signals
         normalized = pd.DataFrame(self.df_original.iloc[:, 0])
-        i = 0
-        for s in self.signals:
-            if s == 1:
-                normalized = normalized.join(normalized_max.iloc[:, i])
-            else:
-                normalized = normalized.join(normalized_min.iloc[:, i])
-            i = i + 1
+        if ignore_signals is True:
+            normalized = normalized.join(normalized_max.iloc[:, :])
+        else:
+            i = 0
+            for s in self.signals:
+                if s == 1:
+                    normalized = normalized.join(normalized_max.iloc[:, i])
+                else:
+                    normalized = normalized.join(normalized_min.iloc[:, i])
+                i = i + 1
         
         self.df_normalized = normalized
 
-    def __norm_Vector(self):
+    def __norm_Vector(self, ignore_signals=False):
         # _max for maximizing 
         normalized_max = self.df_original.iloc[:, 1:]/np.sqrt(self.df_original.iloc[:, 1:].pow(2).sum(axis=0))
         # _min for minimizing 
@@ -329,17 +361,20 @@ class MCDA:
        
         # make nomalized matrix based in signals
         normalized = pd.DataFrame(self.df_original.iloc[:, 0])
-        i = 0
-        for s in self.signals:
-            if s == 1:
-                normalized = normalized.join(normalized_max.iloc[:, i])
-            else:
-                normalized = normalized.join(normalized_min.iloc[:, i])
-            i = i + 1
+        if ignore_signals is True:
+            normalized = normalized.join(normalized_max.iloc[:, :])
+        else:
+            i = 0
+            for s in self.signals:
+                if s == 1:
+                    normalized = normalized.join(normalized_max.iloc[:, i])
+                else:
+                    normalized = normalized.join(normalized_min.iloc[:, i])
+                i = i + 1
         
         self.df_normalized = normalized
 
-    def __norm_TopsisOriginal(self):
+
         # _max for maximizing 
         normalized_topsis = self.df_original.iloc[:, 1:]/np.sqrt(self.df_original.iloc[:, 1:].pow(2).sum(axis=0))
         
